@@ -1,22 +1,17 @@
-import os
-
 import typer
 from dotenv import load_dotenv
 
+from kclii.database.database import Base, engine
 from kclii.modules.profiles import profiles
-from kclii.scripts.scripts import install_scripts
+
+
+import kclii.modules.profiles.models
 
 load_dotenv()
 app = typer.Typer(pretty_exceptions_enable=False)
 app.add_typer(profiles.app, name="profile")
 
 
-@app.command()
-def init():
-    print("Init configurations")
-    install_scripts()
-
-
 @app.command()
 def hello(name: str = ""):
     print(f"Welcome sr! {name}")
@@ -24,13 +19,9 @@ def hello(name: str = ""):
 
 @app.command()
 def version() -> None:
-    print("0.1.7")
+    print("0.1.10")
 
 
 if __name__ == "__main__":
-    if os.getuid() != 0:
-        import kclii.modules.profiles.models
-        from kclii.database.database import Base, engine
-
-        Base.metadata.create_all(engine)
+    Base.metadata.create_all(engine)
     app()
