@@ -20,6 +20,16 @@ class ProfileModel(Base):
     updated_at = Column(DateTime(timezone=True), onupdate=func.now())
 
 
+class CurrentModel(Base):
+    __tablename__ = "current"
+
+    id = Column(Integer, Sequence("current_id_seq"), primary_key=True)
+    profile = relationship("ProfileModel", uselist=False)
+    profile_id = Column(Integer, ForeignKey(ProfileModel.id))
+    created_at = Column(DateTime(timezone=True), server_default=func.now())
+    updated_at = Column(DateTime(timezone=True), onupdate=func.now())
+
+
 class EnvironmentVariablesModel(Base):
     __tablename__ = "environment_variables"
 
